@@ -101,16 +101,17 @@ impl crate::model::Model<DB> for Person {
     where
         'a: 'e,
         E: 'e + sqlx::Executor<'e, Database = DB>,
-        Arg: 'a + Send + for<'r> sqlx::Encode<'r, DB> + sqlx::Type<DB>,
+        Arg: 'a + Send + sqlx::Encode<'a, DB> + sqlx::Type<DB>,
     {
-        let text = format!(
-            "SELECT * FROM {} WHERE {} = {}",
-            Self::table_name(),
-            Self::primary_key_column(),
-            PLACEHOLDER,
-        );
+        // let text = format!(
+        //     "SELECT * FROM {} WHERE {} = {}",
+        //     Self::table_name(),
+        //     Self::primary_key_column(),
+        //     PLACEHOLDER,
+        // );
+        let text = "SELECT * FROM person WHERE id = ?";
         Box::pin(async move {
-            sqlx::query_as::<DB, Self>(&text)
+            sqlx::query_as::<DB, Self>(text)
                 .bind(id)
                 .fetch_one(db) // executor outlives the
                 .await
@@ -125,9 +126,13 @@ impl crate::model::Model<DB> for Person {
     }
 }
 
-impl HasQueryBuilder<DB, Box<dyn Iterator<Item = String> + Send>> for Person {
-    fn select<'a>() -> SelectQueryBuilder<'a, DB, Self, Box<dyn Iterator<Item = String> + Send>> {
-        SelectQueryBuilder::default().column(&format!("{}.*", Self::table_name()))
+
+use ormlite_core::query_builder::Placeholder;
+
+
+impl HasQueryBuilder<DB> for Person {
+    fn select<'a>() -> SelectQueryBuilder<'a, DB, Self> {
+        SelectQueryBuilder::new(Placeholder::question_mark()).column(&format!("{}.*", Self::table_name()))
     }
 }
 
